@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2016-2020 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2021 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -39,14 +39,14 @@ G_DECLARE_FINAL_TYPE (AscCanvas, asc_canvas, ASC, CANVAS, GObject)
  * @ASC_CANVAS_ERROR_DRAWING:	Drawing operation failed.
  * @ASC_CANVAS_ERROR_FONT:	Issue with font or font selection.
  *
- * A metadata processing error.
+ * A drawing error.
  **/
 typedef enum {
 	ASC_CANVAS_ERROR_FAILED,
 	ASC_CANVAS_ERROR_DRAWING,
 	ASC_CANVAS_ERROR_FONT,
 	/*< private >*/
-	ASC_CANVASE_RROR_LAST
+	ASC_CANVAS_ERROR_LAST
 } AscCanvasError;
 
 #define	ASC_CANVAS_ERROR	asc_canvas_error_quark ()
@@ -58,7 +58,7 @@ AscCanvas	*asc_canvas_new (gint width,
 guint		asc_canvas_get_width (AscCanvas *canvas);
 guint		asc_canvas_get_height (AscCanvas *canvas);
 
-gboolean	asc_canvas_render_svg(AscCanvas* canvas,
+gboolean	asc_canvas_render_svg (AscCanvas* canvas,
 					GInputStream *stream,
 					GError** error);
 
