@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016-2020 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2021 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -39,6 +39,7 @@ namespace AppStream {
 class Icon;
 class Screenshot;
 class Release;
+class Relation;
 class Suggested;
 
 class ComponentData;
@@ -47,7 +48,7 @@ class ComponentData;
  * Describes a software component (application, driver, font, ...)
  */
 class APPSTREAMQT_EXPORT Component {
-Q_GADGET
+    Q_GADGET
     friend class Pool;
     public:
         enum Kind  {
@@ -181,6 +182,7 @@ Q_GADGET
         QStringList categories() const;
         void addCategory(const QString& category);
         bool hasCategory(const QString& category) const;
+        bool isMemberOfCategory(const AppStream::Category& category) const;
 
         QStringList extends() const;
         void setExtends(const QStringList& extends);
@@ -189,6 +191,10 @@ Q_GADGET
         QList<AppStream::Component> addons() const;
         void addAddon(const AppStream::Component& addon);
 
+        QList<AppStream::Relation> recommends() const;
+        QList<AppStream::Relation> requires() const;
+        void addRelation(const AppStream::Relation &relation);
+
         QStringList languages() const;
         int language(const QString& locale) const;
         void addLanguage(const QString& locale, int percentage);
@@ -233,6 +239,9 @@ Q_GADGET
         uint searchMatches(const QString& term) const;
         uint searchMatchesAll(const QStringList& terms) const;
 
+        uint sortScore() const;
+        void setSortScore(uint score);
+
         MergeKind mergeKind() const;
         void setMergeKind(MergeKind kind);
 
@@ -244,7 +253,8 @@ Q_GADGET
         AppStream::ContentRating contentRating(const QString& kind) const;
         void addContentRating(const AppStream::ContentRating& contentRating);
 
-        bool isMemberOfCategory(const AppStream::Category& category) const;
+        QString nameVariantSuffix() const;
+        void setNameVariantSuffix(const QString& variantSuffix, const QString& lang = {});
 
         bool isIgnored() const;
         bool isValid() const;
