@@ -73,9 +73,9 @@ Q_OBJECT
 
         /**
          * \return true on success. False on failure
-	 *
-	 * Loads all available metadata and opens the cache. In case of an error,
-	 * \sa lastError() will contain the error message.
+         *
+         * Loads all available metadata and opens the cache. In case of an error,
+         * \sa lastError() will contain the error message.
          */
         bool load();
 
@@ -91,10 +91,10 @@ Q_OBJECT
          */
         void clear();
 
-	/**
+        /**
          * \return The last error message received.
          */
-	QString lastError() const;
+        QString lastError() const;
 
         /**
          * Add a component to the pool.
@@ -109,7 +109,7 @@ Q_OBJECT
 
         QList<AppStream::Component> componentsByKind(Component::Kind kind) const;
 
-        QList<AppStream::Component> componentsByCategories(const QStringList categories) const;
+        QList<AppStream::Component> componentsByCategories(const QStringList& categories) const;
 
         QList<AppStream::Component> componentsByLaunchable(Launchable::Kind kind, const QString& value) const;
 
@@ -126,6 +126,9 @@ Q_OBJECT
         uint cacheFlags() const;
         void setCacheFlags(uint flags);
 
+        void setCacheLocation(const QString &path);
+        QString cacheLocation() const;
+
     private:
         Q_DISABLE_COPY(Pool);
         QScopedPointer<PoolPrivate> d;
