@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2016-2020 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2021 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -53,6 +53,7 @@ struct _AsBundleClass
  * @AS_BUNDLE_KIND_APPIMAGE:	An AppImageKit bundle
  * @AS_BUNDLE_KIND_SNAP:	A Snap/Snappy bundle
  * @AS_BUNDLE_KIND_TARBALL:	A (maybe compressed) tarball.
+ * @AS_BUNDLE_KIND_CABINET:	Cabinet firmware deployment
  *
  * The bundle type.
  **/
@@ -64,6 +65,7 @@ typedef enum {
 	AS_BUNDLE_KIND_APPIMAGE,
 	AS_BUNDLE_KIND_SNAP,
 	AS_BUNDLE_KIND_TARBALL,
+	AS_BUNDLE_KIND_CABINET,
 	/*< private >*/
 	AS_BUNDLE_KIND_LAST
 } AsBundleKind;
