@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2012-2017 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2012-2021 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -26,7 +26,7 @@
 #define __AS_CONTEXT_H
 
 #include <glib-object.h>
-#include "as-metadata.h"
+#include "as-enums.h"
 
 G_BEGIN_DECLS
 
@@ -45,6 +45,39 @@ struct _AsContextClass
 	void (*_as_reserved6) (void);
 };
 
+/**
+ * AsFormatVersion:
+ * @AS_FORMAT_VERSION_V0_6:	0.6
+ * @AS_FORMAT_VERSION_V0_7:	0.7
+ * @AS_FORMAT_VERSION_V0_8:	0.8
+ * @AS_FORMAT_VERSION_V0_9:	0.9
+ * @AS_FORMAT_VERSION_V0_10:	0.10
+ * @AS_FORMAT_VERSION_V0_11:	0.11
+ * @AS_FORMAT_VERSION_V0_12:	0.12
+ * @AS_FORMAT_VERSION_V0_13:	0.13
+ * @AS_FORMAT_VERSION_V0_14:	0.14
+ *
+ * Format version / API level of the AppStream metadata.
+ **/
+typedef enum {
+	AS_FORMAT_VERSION_V0_6,
+	AS_FORMAT_VERSION_V0_7,
+	AS_FORMAT_VERSION_V0_8,
+	AS_FORMAT_VERSION_V0_9,
+	AS_FORMAT_VERSION_V0_10,
+	AS_FORMAT_VERSION_V0_11,
+	AS_FORMAT_VERSION_V0_12,
+	AS_FORMAT_VERSION_V0_13,
+	AS_FORMAT_VERSION_V0_14,
+	/*< private >*/
+	AS_FORMAT_VERSION_LAST
+} AsFormatVersion;
+
+#define AS_FORMAT_VERSION_CURRENT AS_FORMAT_VERSION_V0_14
+
+const gchar		*as_format_version_to_string (AsFormatVersion version);
+AsFormatVersion		 as_format_version_from_string (const gchar *version_str);
+
 AsContext		*as_context_new (void);
 
 AsFormatVersion		as_context_get_format_version (AsContext *ctx);
@@ -72,20 +105,12 @@ const gchar		*as_context_get_media_baseurl (AsContext *ctx);
 void			as_context_set_media_baseurl (AsContext *ctx,
 						      const gchar *value);
 
-const gchar		*as_context_get_architecture (AsContext *ctx);
-void			as_context_set_architecture (AsContext *ctx,
-						     const gchar *value);
-
-gboolean		as_context_get_all_locale_enabled (AsContext *ctx);
+gboolean		as_context_get_locale_all_enabled (AsContext *ctx);
 
 const gchar		*as_context_get_filename (AsContext *ctx);
 void			as_context_set_filename (AsContext *ctx,
 					       const gchar *fname);
 
-gboolean		as_context_get_internal_mode (AsContext *ctx);
-void			as_context_set_internal_mode (AsContext *ctx,
-						      gboolean enabled);
-
 G_END_DECLS
 
 #endif /* __AS_CONTEXT_H */
