@@ -28,7 +28,7 @@ eatmydata apt-get install -yq --no-install-recommends \
     libxml2-dev \
     libyaml-dev \
     liblmdb-dev \
-    libsoup2.4-dev \
+    libcurl4-gnutls-dev \
     gtk-doc-tools \
     libgirepository1.0-dev \
     qtbase5-dev \
